@@ -31,7 +31,8 @@ impl AssetProtocol for PngImageAssetProtocol {
     fn on_load(&mut self, data: Vec<u8>) -> AssetLoadResult {
         let stream = Cursor::new(&data);
         let decoder = png::Decoder::new(stream);
-        let (info, _) = decoder.read_info().unwrap();
+        let reader = decoder.read_info().unwrap();
+        let info = reader.info();
         let width = info.width as usize;
         let height = info.height as usize;
         AssetLoadResult::Data(Box::new(PngImageAsset {
